Exceptions
==========

.. autoclass:: qtrio.QTrioException
.. autoclass:: qtrio.NoOutcomesError
.. autoclass:: qtrio.EventTypeRegistrationError
.. autoclass:: qtrio.EventTypeRegistrationFailedError
.. autoclass:: qtrio.RequestedEventTypeUnavailableError
.. autoclass:: qtrio.EventTypeAlreadyRegisteredError
.. autoclass:: qtrio.ReturnCodeError
.. autoclass:: qtrio.InternalError
.. autoclass:: qtrio.UserCancelledError
.. autoclass:: qtrio.InvalidInputError
